@@ -592,3 +592,16 @@ NULL
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(c("."))
 }
+
+get_pkg_version <- function(pkg_name){
+  vs <- unlist(utils::packageVersion(pkg_name))
+  list("major" = vs[[1]],
+       "minor" = vs[[2]],
+       "patch" = vs[[3]],
+       "dev" = ifelse(length(vs) > 3, vs[[4]], integer(0)))
+}
+
+is_checkmate_v2_1 <- function(){
+  v <- get_pkg_version("checkmate")
+  v$major == 2 && v$minor >= 1
+}
